<?php
include "../html.php";
html_top("keyanalyze August 2001",1);
?>
<P><A href="index.php">[Back to Keyring Analysis Page]</A>

<P><B>Key Analysis 10 Aug 2001</B>

<P>The following stats are being pulled from a keyring that was
exported from 
<A href="http://pgp.dtype.org/">pgp.dtype.org</A> on August 9, 2001.
Before reading this, please be sure to
view the 
<A href="explanation.php">explanation of this analysis</A> and read
the <A href="keyfaq.php">FAQ</A> before asking me any questions
about it.

<P>The strong set MSD raw analysis is 
<A href="output/200108/msd-sorted-200108.txt.gz">available here</A>. Please
read the <A href="keyfaq.php">FAQ</A> to explain how to read this file.
This file includes all keys reachable from the strong set. Look up
reports for individual keys in the
<A href="output/200108/">raw output directory</A>. Here you can
also see what keys are
signed by each key (otherwise very difficult to find).

<UL><LI><A href="output/200108/">Output directory, including individual
key reports</A></UL>

<P><B>New This Month</B>


<P><B>General statistics</B>
<TABLE width="80%">
<TR><TD>Size of binary keyring (bytes):</TD>
<TD><TD align="right">1,863,975,684</TD><TD>(+0.56%)</TD></TR>
<TR><TD>Number of keys:</TD>
<TD><TD align="right">1,583,621</TD><TD>(+0.37%)</TD></TR>
<TR><TD>Non-revoked keys with at least one non-self sig:</TD>
<TD><TD align="right">148,845</TD><TD>(+0.77%)</TD></TR>
<TR><TD>Total non-self sigs on those keys:</TD>
<TD><TD align="right">306,035 302,662</TD><TD>(+1.10%)</TD></TR>
</TABLE>
<P><B>The "strong set"</B>
<TABLE width="80%">
<TR><TD>Size of largest strongly connected set:</TD>
<TD><TD align="right">10,153</TD><TD>(+6.18%)</TD></TR>
<TR><TD>Keys that have signed this set:</TD>
<TD><TD align="right">14,811</TD><TD>(+6.04%)</TD></TR>
<TR><TD>Keys that this set has signed (target of MSD calculations):</TD>
<TD><TD align="right">40,249</TD><TD>(+5.27%)</TD></TR>
</TABLE>

<P><B>Best connected keys (shortest distance to)</B>
<P>Please read about the mean shortest distance (MSD) calculated here
in the <A href="explanation.php">analysis explanation</A>. Here are the
top 50 keys. Look for your own key in this month's raw analysis
(see above). Note that the only keys analyzed were those reachable from
the strong
set. I've included some of my own comments on people I recognize. I'm
sorry if you're listed here without a comment. If you email me a quick
phrase to describe what you do that would be of interest to readers, I'll
put it in.
<P>The average MSD is 6.6224, in the set of 10,153. The median value
is 6.1993.
<P>Go to <A href="http://pgp.dtype.org/pgpnet/pks-commands.html">this
keyserver's web interface</A> to look up these keys.

<P>
<TABLE width="100%">
<TR><TD><B>Rank</B></TD><TD><B>Hex ID (last 32b)</B></TD>
<TD><B>Key Name (Identifier)</B></TD><TD><I><B>Comments</B></I></TD>
<TD align="right"><B>MSD</B></TD></TR>
